# Stage Model
[![Build Status](https://travis-ci.com/ihmeuw-msca/stagemodel.svg?branch=master)](https://travis-ci.org/ihmeuw-msca/stagemodel)

This is a package for stage-wise model.
Used for Goal Keepers 2020 project.
